# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .associate_monitored_resources_details import AssociateMonitoredResourcesDetails
from .association_resource_details import AssociationResourceDetails
from .change_monitored_resource_compartment_details import ChangeMonitoredResourceCompartmentDetails
from .connection_details import ConnectionDetails
from .create_discovery_job_details import CreateDiscoveryJobDetails
from .create_monitored_resource_details import CreateMonitoredResourceDetails
from .credential_collection import CredentialCollection
from .credential_details import CredentialDetails
from .credential_property import CredentialProperty
from .disassociate_monitored_resources_details import DisassociateMonitoredResourcesDetails
from .discovery_details import DiscoveryDetails
from .discovery_job import DiscoveryJob
from .discovery_job_collection import DiscoveryJobCollection
from .discovery_job_log_collection import DiscoveryJobLogCollection
from .discovery_job_log_summary import DiscoveryJobLogSummary
from .discovery_job_summary import DiscoveryJobSummary
from .encrypted_credentials import EncryptedCredentials
from .monitored_resource import MonitoredResource
from .monitored_resource_alias_credential import MonitoredResourceAliasCredential
from .monitored_resource_alias_source_credential import MonitoredResourceAliasSourceCredential
from .monitored_resource_association import MonitoredResourceAssociation
from .monitored_resource_association_summary import MonitoredResourceAssociationSummary
from .monitored_resource_associations_collection import MonitoredResourceAssociationsCollection
from .monitored_resource_collection import MonitoredResourceCollection
from .monitored_resource_credential import MonitoredResourceCredential
from .monitored_resource_member_summary import MonitoredResourceMemberSummary
from .monitored_resource_members_collection import MonitoredResourceMembersCollection
from .monitored_resource_property import MonitoredResourceProperty
from .monitored_resource_summary import MonitoredResourceSummary
from .plain_text_credentials import PlainTextCredentials
from .pre_existing_credentials import PreExistingCredentials
from .property_details import PropertyDetails
from .search_monitored_resource_associations_details import SearchMonitoredResourceAssociationsDetails
from .search_monitored_resource_members_details import SearchMonitoredResourceMembersDetails
from .search_monitored_resources_details import SearchMonitoredResourcesDetails
from .update_monitored_resource_details import UpdateMonitoredResourceDetails
from .work_request import WorkRequest
from .work_request_error import WorkRequestError
from .work_request_error_collection import WorkRequestErrorCollection
from .work_request_log_entry import WorkRequestLogEntry
from .work_request_log_entry_collection import WorkRequestLogEntryCollection
from .work_request_resource import WorkRequestResource
from .work_request_summary import WorkRequestSummary
from .work_request_summary_collection import WorkRequestSummaryCollection

# Maps type names to classes for stack_monitoring services.
stack_monitoring_type_mapping = {
    "AssociateMonitoredResourcesDetails": AssociateMonitoredResourcesDetails,
    "AssociationResourceDetails": AssociationResourceDetails,
    "ChangeMonitoredResourceCompartmentDetails": ChangeMonitoredResourceCompartmentDetails,
    "ConnectionDetails": ConnectionDetails,
    "CreateDiscoveryJobDetails": CreateDiscoveryJobDetails,
    "CreateMonitoredResourceDetails": CreateMonitoredResourceDetails,
    "CredentialCollection": CredentialCollection,
    "CredentialDetails": CredentialDetails,
    "CredentialProperty": CredentialProperty,
    "DisassociateMonitoredResourcesDetails": DisassociateMonitoredResourcesDetails,
    "DiscoveryDetails": DiscoveryDetails,
    "DiscoveryJob": DiscoveryJob,
    "DiscoveryJobCollection": DiscoveryJobCollection,
    "DiscoveryJobLogCollection": DiscoveryJobLogCollection,
    "DiscoveryJobLogSummary": DiscoveryJobLogSummary,
    "DiscoveryJobSummary": DiscoveryJobSummary,
    "EncryptedCredentials": EncryptedCredentials,
    "MonitoredResource": MonitoredResource,
    "MonitoredResourceAliasCredential": MonitoredResourceAliasCredential,
    "MonitoredResourceAliasSourceCredential": MonitoredResourceAliasSourceCredential,
    "MonitoredResourceAssociation": MonitoredResourceAssociation,
    "MonitoredResourceAssociationSummary": MonitoredResourceAssociationSummary,
    "MonitoredResourceAssociationsCollection": MonitoredResourceAssociationsCollection,
    "MonitoredResourceCollection": MonitoredResourceCollection,
    "MonitoredResourceCredential": MonitoredResourceCredential,
    "MonitoredResourceMemberSummary": MonitoredResourceMemberSummary,
    "MonitoredResourceMembersCollection": MonitoredResourceMembersCollection,
    "MonitoredResourceProperty": MonitoredResourceProperty,
    "MonitoredResourceSummary": MonitoredResourceSummary,
    "PlainTextCredentials": PlainTextCredentials,
    "PreExistingCredentials": PreExistingCredentials,
    "PropertyDetails": PropertyDetails,
    "SearchMonitoredResourceAssociationsDetails": SearchMonitoredResourceAssociationsDetails,
    "SearchMonitoredResourceMembersDetails": SearchMonitoredResourceMembersDetails,
    "SearchMonitoredResourcesDetails": SearchMonitoredResourcesDetails,
    "UpdateMonitoredResourceDetails": UpdateMonitoredResourceDetails,
    "WorkRequest": WorkRequest,
    "WorkRequestError": WorkRequestError,
    "WorkRequestErrorCollection": WorkRequestErrorCollection,
    "WorkRequestLogEntry": WorkRequestLogEntry,
    "WorkRequestLogEntryCollection": WorkRequestLogEntryCollection,
    "WorkRequestResource": WorkRequestResource,
    "WorkRequestSummary": WorkRequestSummary,
    "WorkRequestSummaryCollection": WorkRequestSummaryCollection
}



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .ca_bundle import CaBundle
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CertificatesCertificateAuthority(CaBundle):
    """
    Certificate Authority from Certificates Service that should be used on the gateway for TLS validation
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CertificatesCertificateAuthority object with values from keyword arguments. The default value of the :py:attr:`~oci.apigateway.models.CertificatesCertificateAuthority.type` attribute
        of this class is ``CERTIFICATE_AUTHORITY`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this CertificatesCertificateAuthority.
            Allowed values for this property are: "CA_BUNDLE", "CERTIFICATE_AUTHORITY"
        :type type: str

        :param certificate_authority_id:
            The value to assign to the certificate_authority_id property of this CertificatesCertificateAuthority.
        :type certificate_authority_id: str

        """
        self.swagger_types = {
            'type': 'str',
            'certificate_authority_id': 'str'
        }

        self.attribute_map = {
            'type': 'type',
            'certificate_authority_id': 'certificateAuthorityId'
        }

        self._type = None
        self._certificate_authority_id = None
        self._type = 'CERTIFICATE_AUTHORITY'

    @property
    def certificate_authority_id(self):
        """
        Gets the certificate_authority_id of this CertificatesCertificateAuthority.
        The `OCID`__ of the resource.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The certificate_authority_id of this CertificatesCertificateAuthority.
        :rtype: str
        """
        return self._certificate_authority_id

    @certificate_authority_id.setter
    def certificate_authority_id(self, certificate_authority_id):
        """
        Sets the certificate_authority_id of this CertificatesCertificateAuthority.
        The `OCID`__ of the resource.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param certificate_authority_id: The certificate_authority_id of this CertificatesCertificateAuthority.
        :type: str
        """
        self._certificate_authority_id = certificate_authority_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .android_channel import AndroidChannel
from .app_event_channel import AppEventChannel
from .application_channel import ApplicationChannel
from .authentication_provider import AuthenticationProvider
from .authentication_provider_collection import AuthenticationProviderCollection
from .authentication_provider_summary import AuthenticationProviderSummary
from .bot import Bot
from .change_oda_instance_compartment_details import ChangeOdaInstanceCompartmentDetails
from .channel import Channel
from .channel_collection import ChannelCollection
from .channel_summary import ChannelSummary
from .clone_digital_assistant_details import CloneDigitalAssistantDetails
from .clone_skill_details import CloneSkillDetails
from .configure_digital_assistant_parameters_details import ConfigureDigitalAssistantParametersDetails
from .cortana_channel import CortanaChannel
from .create_android_channel_details import CreateAndroidChannelDetails
from .create_android_channel_result import CreateAndroidChannelResult
from .create_app_event_channel_details import CreateAppEventChannelDetails
from .create_app_event_channel_result import CreateAppEventChannelResult
from .create_application_channel_details import CreateApplicationChannelDetails
from .create_application_channel_result import CreateApplicationChannelResult
from .create_authentication_provider_details import CreateAuthenticationProviderDetails
from .create_channel_details import CreateChannelDetails
from .create_channel_result import CreateChannelResult
from .create_cortana_channel_details import CreateCortanaChannelDetails
from .create_cortana_channel_result import CreateCortanaChannelResult
from .create_digital_assistant_details import CreateDigitalAssistantDetails
from .create_digital_assistant_version_details import CreateDigitalAssistantVersionDetails
from .create_facebook_channel_details import CreateFacebookChannelDetails
from .create_facebook_channel_result import CreateFacebookChannelResult
from .create_imported_package_details import CreateImportedPackageDetails
from .create_ios_channel_details import CreateIosChannelDetails
from .create_ios_channel_result import CreateIosChannelResult
from .create_ms_teams_channel_details import CreateMSTeamsChannelDetails
from .create_ms_teams_channel_result import CreateMSTeamsChannelResult
from .create_new_digital_assistant_details import CreateNewDigitalAssistantDetails
from .create_new_skill_details import CreateNewSkillDetails
from .create_oss_channel_details import CreateOSSChannelDetails
from .create_oss_channel_result import CreateOSSChannelResult
from .create_oda_instance_attachment_details import CreateOdaInstanceAttachmentDetails
from .create_oda_instance_details import CreateOdaInstanceDetails
from .create_osvc_channel_details import CreateOsvcChannelDetails
from .create_osvc_channel_result import CreateOsvcChannelResult
from .create_service_cloud_channel_details import CreateServiceCloudChannelDetails
from .create_service_cloud_channel_result import CreateServiceCloudChannelResult
from .create_skill_details import CreateSkillDetails
from .create_skill_parameter_details import CreateSkillParameterDetails
from .create_skill_version_details import CreateSkillVersionDetails
from .create_slack_channel_details import CreateSlackChannelDetails
from .create_slack_channel_result import CreateSlackChannelResult
from .create_test_channel_result import CreateTestChannelResult
from .create_translator_details import CreateTranslatorDetails
from .create_twilio_channel_details import CreateTwilioChannelDetails
from .create_twilio_channel_result import CreateTwilioChannelResult
from .create_web_channel_details import CreateWebChannelDetails
from .create_web_channel_result import CreateWebChannelResult
from .create_webhook_channel_details import CreateWebhookChannelDetails
from .create_webhook_channel_result import CreateWebhookChannelResult
from .default_parameter_values import DefaultParameterValues
from .digital_assistant import DigitalAssistant
from .digital_assistant_collection import DigitalAssistantCollection
from .digital_assistant_parameter import DigitalAssistantParameter
from .digital_assistant_parameter_collection import DigitalAssistantParameterCollection
from .digital_assistant_parameter_summary import DigitalAssistantParameterSummary
from .digital_assistant_parameter_value import DigitalAssistantParameterValue
from .digital_assistant_summary import DigitalAssistantSummary
from .error_body import ErrorBody
from .export_bot_details import ExportBotDetails
from .export_digital_assistant_details import ExportDigitalAssistantDetails
from .export_skill_details import ExportSkillDetails
from .extend_digital_assistant_details import ExtendDigitalAssistantDetails
from .extend_skill_details import ExtendSkillDetails
from .facebook_channel import FacebookChannel
from .import_bot_details import ImportBotDetails
from .import_contract import ImportContract
from .imported_package import ImportedPackage
from .imported_package_summary import ImportedPackageSummary
from .ios_channel import IosChannel
from .ms_teams_channel import MSTeamsChannel
from .metadata_property import MetadataProperty
from .oss_channel import OSSChannel
from .oda_instance import OdaInstance
from .oda_instance_attachment import OdaInstanceAttachment
from .oda_instance_attachment_collection import OdaInstanceAttachmentCollection
from .oda_instance_attachment_owner import OdaInstanceAttachmentOwner
from .oda_instance_attachment_summary import OdaInstanceAttachmentSummary
from .oda_instance_owner import OdaInstanceOwner
from .oda_instance_summary import OdaInstanceSummary
from .osvc_channel import OsvcChannel
from .package import Package
from .package_summary import PackageSummary
from .parameter import Parameter
from .parameter_definition import ParameterDefinition
from .resource_type_default_parameter_values import ResourceTypeDefaultParameterValues
from .resource_type_import_contract import ResourceTypeImportContract
from .resource_type_metadata import ResourceTypeMetadata
from .restricted_operation import RestrictedOperation
from .service_cloud_channel import ServiceCloudChannel
from .skill import Skill
from .skill_collection import SkillCollection
from .skill_parameter import SkillParameter
from .skill_parameter_collection import SkillParameterCollection
from .skill_parameter_summary import SkillParameterSummary
from .skill_summary import SkillSummary
from .slack_channel import SlackChannel
from .storage_location import StorageLocation
from .test_channel import TestChannel
from .translator import Translator
from .translator_collection import TranslatorCollection
from .translator_summary import TranslatorSummary
from .twilio_channel import TwilioChannel
from .update_android_channel_details import UpdateAndroidChannelDetails
from .update_app_event_channel_details import UpdateAppEventChannelDetails
from .update_application_channel_details import UpdateApplicationChannelDetails
from .update_authentication_provider_details import UpdateAuthenticationProviderDetails
from .update_channel_details import UpdateChannelDetails
from .update_cortana_channel_details import UpdateCortanaChannelDetails
from .update_digital_assistant_details import UpdateDigitalAssistantDetails
from .update_digital_assistant_parameter_details import UpdateDigitalAssistantParameterDetails
from .update_facebook_channel_details import UpdateFacebookChannelDetails
from .update_imported_package_details import UpdateImportedPackageDetails
from .update_ios_channel_details import UpdateIosChannelDetails
from .update_ms_teams_channel_details import UpdateMSTeamsChannelDetails
from .update_oss_channel_details import UpdateOSSChannelDetails
from .update_oda_instance_attachment_details import UpdateOdaInstanceAttachmentDetails
from .update_oda_instance_details import UpdateOdaInstanceDetails
from .update_osvc_channel_details import UpdateOsvcChannelDetails
from .update_service_cloud_channel_details import UpdateServiceCloudChannelDetails
from .update_skill_details import UpdateSkillDetails
from .update_skill_parameter_details import UpdateSkillParameterDetails
from .update_slack_channel_details import UpdateSlackChannelDetails
from .update_translator_details import UpdateTranslatorDetails
from .update_twilio_channel_details import UpdateTwilioChannelDetails
from .update_web_channel_details import UpdateWebChannelDetails
from .update_webhook_channel_details import UpdateWebhookChannelDetails
from .web_channel import WebChannel
from .webhook_channel import WebhookChannel
from .work_request import WorkRequest
from .work_request_error import WorkRequestError
from .work_request_log_entry import WorkRequestLogEntry
from .work_request_resource import WorkRequestResource
from .work_request_summary import WorkRequestSummary

# Maps type names to classes for oda services.
oda_type_mapping = {
    "AndroidChannel": AndroidChannel,
    "AppEventChannel": AppEventChannel,
    "ApplicationChannel": ApplicationChannel,
    "AuthenticationProvider": AuthenticationProvider,
    "AuthenticationProviderCollection": AuthenticationProviderCollection,
    "AuthenticationProviderSummary": AuthenticationProviderSummary,
    "Bot": Bot,
    "ChangeOdaInstanceCompartmentDetails": ChangeOdaInstanceCompartmentDetails,
    "Channel": Channel,
    "ChannelCollection": ChannelCollection,
    "ChannelSummary": ChannelSummary,
    "CloneDigitalAssistantDetails": CloneDigitalAssistantDetails,
    "CloneSkillDetails": CloneSkillDetails,
    "ConfigureDigitalAssistantParametersDetails": ConfigureDigitalAssistantParametersDetails,
    "CortanaChannel": CortanaChannel,
    "CreateAndroidChannelDetails": CreateAndroidChannelDetails,
    "CreateAndroidChannelResult": CreateAndroidChannelResult,
    "CreateAppEventChannelDetails": CreateAppEventChannelDetails,
    "CreateAppEventChannelResult": CreateAppEventChannelResult,
    "CreateApplicationChannelDetails": CreateApplicationChannelDetails,
    "CreateApplicationChannelResult": CreateApplicationChannelResult,
    "CreateAuthenticationProviderDetails": CreateAuthenticationProviderDetails,
    "CreateChannelDetails": CreateChannelDetails,
    "CreateChannelResult": CreateChannelResult,
    "CreateCortanaChannelDetails": CreateCortanaChannelDetails,
    "CreateCortanaChannelResult": CreateCortanaChannelResult,
    "CreateDigitalAssistantDetails": CreateDigitalAssistantDetails,
    "CreateDigitalAssistantVersionDetails": CreateDigitalAssistantVersionDetails,
    "CreateFacebookChannelDetails": CreateFacebookChannelDetails,
    "CreateFacebookChannelResult": CreateFacebookChannelResult,
    "CreateImportedPackageDetails": CreateImportedPackageDetails,
    "CreateIosChannelDetails": CreateIosChannelDetails,
    "CreateIosChannelResult": CreateIosChannelResult,
    "CreateMSTeamsChannelDetails": CreateMSTeamsChannelDetails,
    "CreateMSTeamsChannelResult": CreateMSTeamsChannelResult,
    "CreateNewDigitalAssistantDetails": CreateNewDigitalAssistantDetails,
    "CreateNewSkillDetails": CreateNewSkillDetails,
    "CreateOSSChannelDetails": CreateOSSChannelDetails,
    "CreateOSSChannelResult": CreateOSSChannelResult,
    "CreateOdaInstanceAttachmentDetails": CreateOdaInstanceAttachmentDetails,
    "CreateOdaInstanceDetails": CreateOdaInstanceDetails,
    "CreateOsvcChannelDetails": CreateOsvcChannelDetails,
    "CreateOsvcChannelResult": CreateOsvcChannelResult,
    "CreateServiceCloudChannelDetails": CreateServiceCloudChannelDetails,
    "CreateServiceCloudChannelResult": CreateServiceCloudChannelResult,
    "CreateSkillDetails": CreateSkillDetails,
    "CreateSkillParameterDetails": CreateSkillParameterDetails,
    "CreateSkillVersionDetails": CreateSkillVersionDetails,
    "CreateSlackChannelDetails": CreateSlackChannelDetails,
    "CreateSlackChannelResult": CreateSlackChannelResult,
    "CreateTestChannelResult": CreateTestChannelResult,
    "CreateTranslatorDetails": CreateTranslatorDetails,
    "CreateTwilioChannelDetails": CreateTwilioChannelDetails,
    "CreateTwilioChannelResult": CreateTwilioChannelResult,
    "CreateWebChannelDetails": CreateWebChannelDetails,
    "CreateWebChannelResult": CreateWebChannelResult,
    "CreateWebhookChannelDetails": CreateWebhookChannelDetails,
    "CreateWebhookChannelResult": CreateWebhookChannelResult,
    "DefaultParameterValues": DefaultParameterValues,
    "DigitalAssistant": DigitalAssistant,
    "DigitalAssistantCollection": DigitalAssistantCollection,
    "DigitalAssistantParameter": DigitalAssistantParameter,
    "DigitalAssistantParameterCollection": DigitalAssistantParameterCollection,
    "DigitalAssistantParameterSummary": DigitalAssistantParameterSummary,
    "DigitalAssistantParameterValue": DigitalAssistantParameterValue,
    "DigitalAssistantSummary": DigitalAssistantSummary,
    "ErrorBody": ErrorBody,
    "ExportBotDetails": ExportBotDetails,
    "ExportDigitalAssistantDetails": ExportDigitalAssistantDetails,
    "ExportSkillDetails": ExportSkillDetails,
    "ExtendDigitalAssistantDetails": ExtendDigitalAssistantDetails,
    "ExtendSkillDetails": ExtendSkillDetails,
    "FacebookChannel": FacebookChannel,
    "ImportBotDetails": ImportBotDetails,
    "ImportContract": ImportContract,
    "ImportedPackage": ImportedPackage,
    "ImportedPackageSummary": ImportedPackageSummary,
    "IosChannel": IosChannel,
    "MSTeamsChannel": MSTeamsChannel,
    "MetadataProperty": MetadataProperty,
    "OSSChannel": OSSChannel,
    "OdaInstance": OdaInstance,
    "OdaInstanceAttachment": OdaInstanceAttachment,
    "OdaInstanceAttachmentCollection": OdaInstanceAttachmentCollection,
    "OdaInstanceAttachmentOwner": OdaInstanceAttachmentOwner,
    "OdaInstanceAttachmentSummary": OdaInstanceAttachmentSummary,
    "OdaInstanceOwner": OdaInstanceOwner,
    "OdaInstanceSummary": OdaInstanceSummary,
    "OsvcChannel": OsvcChannel,
    "Package": Package,
    "PackageSummary": PackageSummary,
    "Parameter": Parameter,
    "ParameterDefinition": ParameterDefinition,
    "ResourceTypeDefaultParameterValues": ResourceTypeDefaultParameterValues,
    "ResourceTypeImportContract": ResourceTypeImportContract,
    "ResourceTypeMetadata": ResourceTypeMetadata,
    "RestrictedOperation": RestrictedOperation,
    "ServiceCloudChannel": ServiceCloudChannel,
    "Skill": Skill,
    "SkillCollection": SkillCollection,
    "SkillParameter": SkillParameter,
    "SkillParameterCollection": SkillParameterCollection,
    "SkillParameterSummary": SkillParameterSummary,
    "SkillSummary": SkillSummary,
    "SlackChannel": SlackChannel,
    "StorageLocation": StorageLocation,
    "TestChannel": TestChannel,
    "Translator": Translator,
    "TranslatorCollection": TranslatorCollection,
    "TranslatorSummary": TranslatorSummary,
    "TwilioChannel": TwilioChannel,
    "UpdateAndroidChannelDetails": UpdateAndroidChannelDetails,
    "UpdateAppEventChannelDetails": UpdateAppEventChannelDetails,
    "UpdateApplicationChannelDetails": UpdateApplicationChannelDetails,
    "UpdateAuthenticationProviderDetails": UpdateAuthenticationProviderDetails,
    "UpdateChannelDetails": UpdateChannelDetails,
    "UpdateCortanaChannelDetails": UpdateCortanaChannelDetails,
    "UpdateDigitalAssistantDetails": UpdateDigitalAssistantDetails,
    "UpdateDigitalAssistantParameterDetails": UpdateDigitalAssistantParameterDetails,
    "UpdateFacebookChannelDetails": UpdateFacebookChannelDetails,
    "UpdateImportedPackageDetails": UpdateImportedPackageDetails,
    "UpdateIosChannelDetails": UpdateIosChannelDetails,
    "UpdateMSTeamsChannelDetails": UpdateMSTeamsChannelDetails,
    "UpdateOSSChannelDetails": UpdateOSSChannelDetails,
    "UpdateOdaInstanceAttachmentDetails": UpdateOdaInstanceAttachmentDetails,
    "UpdateOdaInstanceDetails": UpdateOdaInstanceDetails,
    "UpdateOsvcChannelDetails": UpdateOsvcChannelDetails,
    "UpdateServiceCloudChannelDetails": UpdateServiceCloudChannelDetails,
    "UpdateSkillDetails": UpdateSkillDetails,
    "UpdateSkillParameterDetails": UpdateSkillParameterDetails,
    "UpdateSlackChannelDetails": UpdateSlackChannelDetails,
    "UpdateTranslatorDetails": UpdateTranslatorDetails,
    "UpdateTwilioChannelDetails": UpdateTwilioChannelDetails,
    "UpdateWebChannelDetails": UpdateWebChannelDetails,
    "UpdateWebhookChannelDetails": UpdateWebhookChannelDetails,
    "WebChannel": WebChannel,
    "WebhookChannel": WebhookChannel,
    "WorkRequest": WorkRequest,
    "WorkRequestError": WorkRequestError,
    "WorkRequestLogEntry": WorkRequestLogEntry,
    "WorkRequestResource": WorkRequestResource,
    "WorkRequestSummary": WorkRequestSummary
}



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class BuildSource(object):
    """
    Build source required for the Build stage.
    """

    #: A constant which can be used with the connection_type property of a BuildSource.
    #: This constant has a value of "GITHUB"
    CONNECTION_TYPE_GITHUB = "GITHUB"

    #: A constant which can be used with the connection_type property of a BuildSource.
    #: This constant has a value of "GITLAB"
    CONNECTION_TYPE_GITLAB = "GITLAB"

    #: A constant which can be used with the connection_type property of a BuildSource.
    #: This constant has a value of "BITBUCKET_CLOUD"
    CONNECTION_TYPE_BITBUCKET_CLOUD = "BITBUCKET_CLOUD"

    #: A constant which can be used with the connection_type property of a BuildSource.
    #: This constant has a value of "DEVOPS_CODE_REPOSITORY"
    CONNECTION_TYPE_DEVOPS_CODE_REPOSITORY = "DEVOPS_CODE_REPOSITORY"

    def __init__(self, **kwargs):
        """
        Initializes a new BuildSource object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.devops.models.GithubBuildSource`
        * :class:`~oci.devops.models.BitbucketCloudBuildSource`
        * :class:`~oci.devops.models.DevopsCodeRepositoryBuildSource`
        * :class:`~oci.devops.models.GitlabBuildSource`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this BuildSource.
        :type name: str

        :param connection_type:
            The value to assign to the connection_type property of this BuildSource.
            Allowed values for this property are: "GITHUB", "GITLAB", "BITBUCKET_CLOUD", "DEVOPS_CODE_REPOSITORY", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type connection_type: str

        :param repository_url:
            The value to assign to the repository_url property of this BuildSource.
        :type repository_url: str

        :param branch:
            The value to assign to the branch property of this BuildSource.
        :type branch: str

        """
        self.swagger_types = {
            'name': 'str',
            'connection_type': 'str',
            'repository_url': 'str',
            'branch': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'connection_type': 'connectionType',
            'repository_url': 'repositoryUrl',
            'branch': 'branch'
        }

        self._name = None
        self._connection_type = None
        self._repository_url = None
        self._branch = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['connectionType']

        if type == 'GITHUB':
            return 'GithubBuildSource'

        if type == 'BITBUCKET_CLOUD':
            return 'BitbucketCloudBuildSource'

        if type == 'DEVOPS_CODE_REPOSITORY':
            return 'DevopsCodeRepositoryBuildSource'

        if type == 'GITLAB':
            return 'GitlabBuildSource'
        else:
            return 'BuildSource'

    @property
    def name(self):
        """
        **[Required]** Gets the name of this BuildSource.
        Name of the build source. This must be unique within a build source collection. The name can be used by customers to locate the working directory pertinent to this repository.


        :return: The name of this BuildSource.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this BuildSource.
        Name of the build source. This must be unique within a build source collection. The name can be used by customers to locate the working directory pertinent to this repository.


        :param name: The name of this BuildSource.
        :type: str
        """
        self._name = name

    @property
    def connection_type(self):
        """
        **[Required]** Gets the connection_type of this BuildSource.
        The type of source provider.

        Allowed values for this property are: "GITHUB", "GITLAB", "BITBUCKET_CLOUD", "DEVOPS_CODE_REPOSITORY", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The connection_type of this BuildSource.
        :rtype: str
        """
        return self._connection_type

    @connection_type.setter
    def connection_type(self, connection_type):
        """
        Sets the connection_type of this BuildSource.
        The type of source provider.


        :param connection_type: The connection_type of this BuildSource.
        :type: str
        """
        allowed_values = ["GITHUB", "GITLAB", "BITBUCKET_CLOUD", "DEVOPS_CODE_REPOSITORY"]
        if not value_allowed_none_or_none_sentinel(connection_type, allowed_values):
            connection_type = 'UNKNOWN_ENUM_VALUE'
        self._connection_type = connection_type

    @property
    def repository_url(self):
        """
        **[Required]** Gets the repository_url of this BuildSource.
        URL for the repository.


        :return: The repository_url of this BuildSource.
        :rtype: str
        """
        return self._repository_url

    @repository_url.setter
    def repository_url(self, repository_url):
        """
        Sets the repository_url of this BuildSource.
        URL for the repository.


        :param repository_url: The repository_url of this BuildSource.
        :type: str
        """
        self._repository_url = repository_url

    @property
    def branch(self):
        """
        **[Required]** Gets the branch of this BuildSource.
        Branch name.


        :return: The branch of this BuildSource.
        :rtype: str
        """
        return self._branch

    @branch.setter
    def branch(self, branch):
        """
        Sets the branch of this BuildSource.
        Branch name.


        :param branch: The branch of this BuildSource.
        :type: str
        """
        self._branch = branch

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DataObjectColumnUnit(object):
    """
    Unit details of a data object column.
    """

    #: A constant which can be used with the unit_category property of a DataObjectColumnUnit.
    #: This constant has a value of "DATA_SIZE"
    UNIT_CATEGORY_DATA_SIZE = "DATA_SIZE"

    #: A constant which can be used with the unit_category property of a DataObjectColumnUnit.
    #: This constant has a value of "TIME"
    UNIT_CATEGORY_TIME = "TIME"

    #: A constant which can be used with the unit_category property of a DataObjectColumnUnit.
    #: This constant has a value of "POWER"
    UNIT_CATEGORY_POWER = "POWER"

    #: A constant which can be used with the unit_category property of a DataObjectColumnUnit.
    #: This constant has a value of "TEMPERATURE"
    UNIT_CATEGORY_TEMPERATURE = "TEMPERATURE"

    #: A constant which can be used with the unit_category property of a DataObjectColumnUnit.
    #: This constant has a value of "CORE"
    UNIT_CATEGORY_CORE = "CORE"

    #: A constant which can be used with the unit_category property of a DataObjectColumnUnit.
    #: This constant has a value of "RATE"
    UNIT_CATEGORY_RATE = "RATE"

    #: A constant which can be used with the unit_category property of a DataObjectColumnUnit.
    #: This constant has a value of "FREQUENCY"
    UNIT_CATEGORY_FREQUENCY = "FREQUENCY"

    #: A constant which can be used with the unit_category property of a DataObjectColumnUnit.
    #: This constant has a value of "OTHER_STANDARD"
    UNIT_CATEGORY_OTHER_STANDARD = "OTHER_STANDARD"

    #: A constant which can be used with the unit_category property of a DataObjectColumnUnit.
    #: This constant has a value of "CUSTOM"
    UNIT_CATEGORY_CUSTOM = "CUSTOM"

    def __init__(self, **kwargs):
        """
        Initializes a new DataObjectColumnUnit object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.opsi.models.DataObjectCoreColumnUnit`
        * :class:`~oci.opsi.models.DataObjectTimeColumnUnit`
        * :class:`~oci.opsi.models.DataObjectOtherStandardColumnUnit`
        * :class:`~oci.opsi.models.DataObjectCustomColumnUnit`
        * :class:`~oci.opsi.models.DataObjectTemperatureColumnUnit`
        * :class:`~oci.opsi.models.DataObjectPowerColumnUnit`
        * :class:`~oci.opsi.models.DataObjectRateColumnUnit`
        * :class:`~oci.opsi.models.DataObjectFrequencyColumnUnit`
        * :class:`~oci.opsi.models.DataObjectDataSizeColumnUnit`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param unit_category:
            The value to assign to the unit_category property of this DataObjectColumnUnit.
            Allowed values for this property are: "DATA_SIZE", "TIME", "POWER", "TEMPERATURE", "CORE", "RATE", "FREQUENCY", "OTHER_STANDARD", "CUSTOM", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type unit_category: str

        :param display_name:
            The value to assign to the display_name property of this DataObjectColumnUnit.
        :type display_name: str

        """
        self.swagger_types = {
            'unit_category': 'str',
            'display_name': 'str'
        }

        self.attribute_map = {
            'unit_category': 'unitCategory',
            'display_name': 'displayName'
        }

        self._unit_category = None
        self._display_name = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['unitCategory']

        if type == 'CORE':
            return 'DataObjectCoreColumnUnit'

        if type == 'TIME':
            return 'DataObjectTimeColumnUnit'

        if type == 'OTHER_STANDARD':
            return 'DataObjectOtherStandardColumnUnit'

        if type == 'CUSTOM':
            return 'DataObjectCustomColumnUnit'

        if type == 'TEMPERATURE':
            return 'DataObjectTemperatureColumnUnit'

        if type == 'POWER':
            return 'DataObjectPowerColumnUnit'

        if type == 'RATE':
            return 'DataObjectRateColumnUnit'

        if type == 'FREQUENCY':
            return 'DataObjectFrequencyColumnUnit'

        if type == 'DATA_SIZE':
            return 'DataObjectDataSizeColumnUnit'
        else:
            return 'DataObjectColumnUnit'

    @property
    def unit_category(self):
        """
        **[Required]** Gets the unit_category of this DataObjectColumnUnit.
        Category of the column's unit.

        Allowed values for this property are: "DATA_SIZE", "TIME", "POWER", "TEMPERATURE", "CORE", "RATE", "FREQUENCY", "OTHER_STANDARD", "CUSTOM", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The unit_category of this DataObjectColumnUnit.
        :rtype: str
        """
        return self._unit_category

    @unit_category.setter
    def unit_category(self, unit_category):
        """
        Sets the unit_category of this DataObjectColumnUnit.
        Category of the column's unit.


        :param unit_category: The unit_category of this DataObjectColumnUnit.
        :type: str
        """
        allowed_values = ["DATA_SIZE", "TIME", "POWER", "TEMPERATURE", "CORE", "RATE", "FREQUENCY", "OTHER_STANDARD", "CUSTOM"]
        if not value_allowed_none_or_none_sentinel(unit_category, allowed_values):
            unit_category = 'UNKNOWN_ENUM_VALUE'
        self._unit_category = unit_category

    @property
    def display_name(self):
        """
        Gets the display_name of this DataObjectColumnUnit.
        Display name of the column's unit.


        :return: The display_name of this DataObjectColumnUnit.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this DataObjectColumnUnit.
        Display name of the column's unit.


        :param display_name: The display_name of this DataObjectColumnUnit.
        :type: str
        """
        self._display_name = display_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ImageText(object):
    """
    The detected text.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ImageText object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param words:
            The value to assign to the words property of this ImageText.
        :type words: list[oci.ai_vision.models.Word]

        :param lines:
            The value to assign to the lines property of this ImageText.
        :type lines: list[oci.ai_vision.models.Line]

        """
        self.swagger_types = {
            'words': 'list[Word]',
            'lines': 'list[Line]'
        }

        self.attribute_map = {
            'words': 'words',
            'lines': 'lines'
        }

        self._words = None
        self._lines = None

    @property
    def words(self):
        """
        **[Required]** Gets the words of this ImageText.
        The words recognized in an image.


        :return: The words of this ImageText.
        :rtype: list[oci.ai_vision.models.Word]
        """
        return self._words

    @words.setter
    def words(self, words):
        """
        Sets the words of this ImageText.
        The words recognized in an image.


        :param words: The words of this ImageText.
        :type: list[oci.ai_vision.models.Word]
        """
        self._words = words

    @property
    def lines(self):
        """
        **[Required]** Gets the lines of this ImageText.
        The lines of text recognized in an image.


        :return: The lines of this ImageText.
        :rtype: list[oci.ai_vision.models.Line]
        """
        return self._lines

    @lines.setter
    def lines(self, lines):
        """
        Sets the lines of this ImageText.
        The lines of text recognized in an image.


        :param lines: The lines of this ImageText.
        :type: list[oci.ai_vision.models.Line]
        """
        self._lines = lines

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .base_type import BaseType
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DerivedType(BaseType):
    """
    A `DerivedType` object represents a more complex type that is derived from a set of simple types, for example an `Address` or `SSN` data type.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DerivedType object with values from keyword arguments. The default value of the :py:attr:`~oci.data_connectivity.models.DerivedType.model_type` attribute
        of this class is ``DERIVED_TYPE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this DerivedType.
            Allowed values for this property are: "STRUCTURED_TYPE", "DATA_TYPE", "CONFIGURED_TYPE", "COMPOSITE_TYPE", "DERIVED_TYPE"
        :type model_type: str

        :param key:
            The value to assign to the key property of this DerivedType.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this DerivedType.
        :type model_version: str

        :param parent_ref:
            The value to assign to the parent_ref property of this DerivedType.
        :type parent_ref: oci.data_connectivity.models.ParentReference

        :param name:
            The value to assign to the name property of this DerivedType.
        :type name: str

        :param object_status:
            The value to assign to the object_status property of this DerivedType.
        :type object_status: int

        :param description:
            The value to assign to the description property of this DerivedType.
        :type description: str

        """
        self.swagger_types = {
            'model_type': 'str',
            'key': 'str',
            'model_version': 'str',
            'parent_ref': 'ParentReference',
            'name': 'str',
            'object_status': 'int',
            'description': 'str'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'key': 'key',
            'model_version': 'modelVersion',
            'parent_ref': 'parentRef',
            'name': 'name',
            'object_status': 'objectStatus',
            'description': 'description'
        }

        self._model_type = None
        self._key = None
        self._model_version = None
        self._parent_ref = None
        self._name = None
        self._object_status = None
        self._description = None
        self._model_type = 'DERIVED_TYPE'

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .update_network_address_list_details import UpdateNetworkAddressListDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateNetworkAddressListAddressesDetails(UpdateNetworkAddressListDetails):
    """
    The information to be updated for NetworkAddressListAddresses.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateNetworkAddressListAddressesDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.waf.models.UpdateNetworkAddressListAddressesDetails.type` attribute
        of this class is ``ADDRESSES`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this UpdateNetworkAddressListAddressesDetails.
        :type display_name: str

        :param type:
            The value to assign to the type property of this UpdateNetworkAddressListAddressesDetails.
            Allowed values for this property are: "ADDRESSES", "VCN_ADDRESSES"
        :type type: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateNetworkAddressListAddressesDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateNetworkAddressListAddressesDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this UpdateNetworkAddressListAddressesDetails.
        :type system_tags: dict(str, dict(str, object))

        :param addresses:
            The value to assign to the addresses property of this UpdateNetworkAddressListAddressesDetails.
        :type addresses: list[str]

        """
        self.swagger_types = {
            'display_name': 'str',
            'type': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))',
            'addresses': 'list[str]'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'type': 'type',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags',
            'addresses': 'addresses'
        }

        self._display_name = None
        self._type = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None
        self._addresses = None
        self._type = 'ADDRESSES'

    @property
    def addresses(self):
        """
        Gets the addresses of this UpdateNetworkAddressListAddressesDetails.
        A list of IP address prefixes in CIDR notation.
        To specify all addresses, use \"0.0.0.0/0\" for IPv4 and \"::/0\" for IPv6.


        :return: The addresses of this UpdateNetworkAddressListAddressesDetails.
        :rtype: list[str]
        """
        return self._addresses

    @addresses.setter
    def addresses(self, addresses):
        """
        Sets the addresses of this UpdateNetworkAddressListAddressesDetails.
        A list of IP address prefixes in CIDR notation.
        To specify all addresses, use \"0.0.0.0/0\" for IPv4 and \"::/0\" for IPv6.


        :param addresses: The addresses of this UpdateNetworkAddressListAddressesDetails.
        :type: list[str]
        """
        self._addresses = addresses

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SupportedHostShapeSummary(object):
    """
    A specific compute shape supported by the Oracle Cloud VMware Solution.
    """

    #: A constant which can be used with the supported_operations property of a SupportedHostShapeSummary.
    #: This constant has a value of "CREATE_SDDC"
    SUPPORTED_OPERATIONS_CREATE_SDDC = "CREATE_SDDC"

    #: A constant which can be used with the supported_operations property of a SupportedHostShapeSummary.
    #: This constant has a value of "DELETE_SDDC"
    SUPPORTED_OPERATIONS_DELETE_SDDC = "DELETE_SDDC"

    #: A constant which can be used with the supported_operations property of a SupportedHostShapeSummary.
    #: This constant has a value of "CREATE_ESXI_HOST"
    SUPPORTED_OPERATIONS_CREATE_ESXI_HOST = "CREATE_ESXI_HOST"

    #: A constant which can be used with the supported_operations property of a SupportedHostShapeSummary.
    #: This constant has a value of "DELETE_ESXI_HOST"
    SUPPORTED_OPERATIONS_DELETE_ESXI_HOST = "DELETE_ESXI_HOST"

    #: A constant which can be used with the supported_operations property of a SupportedHostShapeSummary.
    #: This constant has a value of "UPGRADE_HCX"
    SUPPORTED_OPERATIONS_UPGRADE_HCX = "UPGRADE_HCX"

    #: A constant which can be used with the supported_operations property of a SupportedHostShapeSummary.
    #: This constant has a value of "DOWNGRADE_HCX"
    SUPPORTED_OPERATIONS_DOWNGRADE_HCX = "DOWNGRADE_HCX"

    #: A constant which can be used with the supported_operations property of a SupportedHostShapeSummary.
    #: This constant has a value of "CANCEL_DOWNGRADE_HCX"
    SUPPORTED_OPERATIONS_CANCEL_DOWNGRADE_HCX = "CANCEL_DOWNGRADE_HCX"

    #: A constant which can be used with the supported_operations property of a SupportedHostShapeSummary.
    #: This constant has a value of "REFRESH_HCX_LICENSE_STATUS"
    SUPPORTED_OPERATIONS_REFRESH_HCX_LICENSE_STATUS = "REFRESH_HCX_LICENSE_STATUS"

    #: A constant which can be used with the supported_sddc_types property of a SupportedHostShapeSummary.
    #: This constant has a value of "PRODUCTION"
    SUPPORTED_SDDC_TYPES_PRODUCTION = "PRODUCTION"

    #: A constant which can be used with the supported_sddc_types property of a SupportedHostShapeSummary.
    #: This constant has a value of "NON_PRODUCTION"
    SUPPORTED_SDDC_TYPES_NON_PRODUCTION = "NON_PRODUCTION"

    def __init__(self, **kwargs):
        """
        Initializes a new SupportedHostShapeSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this SupportedHostShapeSummary.
        :type name: str

        :param supported_operations:
            The value to assign to the supported_operations property of this SupportedHostShapeSummary.
            Allowed values for items in this list are: "CREATE_SDDC", "DELETE_SDDC", "CREATE_ESXI_HOST", "DELETE_ESXI_HOST", "UPGRADE_HCX", "DOWNGRADE_HCX", "CANCEL_DOWNGRADE_HCX", "REFRESH_HCX_LICENSE_STATUS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type supported_operations: list[str]

        :param shape_family:
            The value to assign to the shape_family property of this SupportedHostShapeSummary.
        :type shape_family: str

        :param default_ocpu_count:
            The value to assign to the default_ocpu_count property of this SupportedHostShapeSummary.
        :type default_ocpu_count: float

        :param supported_ocpu_count:
            The value to assign to the supported_ocpu_count property of this SupportedHostShapeSummary.
        :type supported_ocpu_count: list[float]

        :param supported_sddc_types:
            The value to assign to the supported_sddc_types property of this SupportedHostShapeSummary.
            Allowed values for items in this list are: "PRODUCTION", "NON_PRODUCTION", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type supported_sddc_types: list[str]

        :param supported_vmware_software_versions:
            The value to assign to the supported_vmware_software_versions property of this SupportedHostShapeSummary.
        :type supported_vmware_software_versions: list[str]

        :param description:
            The value to assign to the description property of this SupportedHostShapeSummary.
        :type description: str

        :param is_support_shielded_instances:
            The value to assign to the is_support_shielded_instances property of this SupportedHostShapeSummary.
        :type is_support_shielded_instances: bool

        """
        self.swagger_types = {
            'name': 'str',
            'supported_operations': 'list[str]',
            'shape_family': 'str',
            'default_ocpu_count': 'float',
            'supported_ocpu_count': 'list[float]',
            'supported_sddc_types': 'list[str]',
            'supported_vmware_software_versions': 'list[str]',
            'description': 'str',
            'is_support_shielded_instances': 'bool'
        }

        self.attribute_map = {
            'name': 'name',
            'supported_operations': 'supportedOperations',
            'shape_family': 'shapeFamily',
            'default_ocpu_count': 'defaultOcpuCount',
            'supported_ocpu_count': 'supportedOcpuCount',
            'supported_sddc_types': 'supportedSddcTypes',
            'supported_vmware_software_versions': 'supportedVmwareSoftwareVersions',
            'description': 'description',
            'is_support_shielded_instances': 'isSupportShieldedInstances'
        }

        self._name = None
        self._supported_operations = None
        self._shape_family = None
        self._default_ocpu_count = None
        self._supported_ocpu_count = None
        self._supported_sddc_types = None
        self._supported_vmware_software_versions = None
        self._description = None
        self._is_support_shielded_instances = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this SupportedHostShapeSummary.
        The name of the supported compute shape.


        :return: The name of this SupportedHostShapeSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this SupportedHostShapeSummary.
        The name of the supported compute shape.


        :param name: The name of this SupportedHostShapeSummary.
        :type: str
        """
        self._name = name

    @property
    def supported_operations(self):
        """
        **[Required]** Gets the supported_operations of this SupportedHostShapeSummary.
        The operations where you can use the shape. The operations can be CREATE_SDDC or CREATE_ESXI_HOST.

        Allowed values for items in this list are: "CREATE_SDDC", "DELETE_SDDC", "CREATE_ESXI_HOST", "DELETE_ESXI_HOST", "UPGRADE_HCX", "DOWNGRADE_HCX", "CANCEL_DOWNGRADE_HCX", "REFRESH_HCX_LICENSE_STATUS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The supported_operations of this SupportedHostShapeSummary.
        :rtype: list[str]
        """
        return self._supported_operations

    @supported_operations.setter
    def supported_operations(self, supported_operations):
        """
        Sets the supported_operations of this SupportedHostShapeSummary.
        The operations where you can use the shape. The operations can be CREATE_SDDC or CREATE_ESXI_HOST.


        :param supported_operations: The supported_operations of this SupportedHostShapeSummary.
        :type: list[str]
        """
        allowed_values = ["CREATE_SDDC", "DELETE_SDDC", "CREATE_ESXI_HOST", "DELETE_ESXI_HOST", "UPGRADE_HCX", "DOWNGRADE_HCX", "CANCEL_DOWNGRADE_HCX", "REFRESH_HCX_LICENSE_STATUS"]
        if supported_operations:
            supported_operations[:] = ['UNKNOWN_ENUM_VALUE' if not value_allowed_none_or_none_sentinel(x, allowed_values) else x for x in supported_operations]
        self._supported_operations = supported_operations

    @property
    def shape_family(self):
        """
        **[Required]** Gets the shape_family of this SupportedHostShapeSummary.
        The family of the shape. ESXi hosts of one SDDC must have the same shape family.


        :return: The shape_family of this SupportedHostShapeSummary.
        :rtype: str
        """
        return self._shape_family

    @shape_family.setter
    def shape_family(self, shape_family):
        """
        Sets the shape_family of this SupportedHostShapeSummary.
        The family of the shape. ESXi hosts of one SDDC must have the same shape family.


        :param shape_family: The shape_family of this SupportedHostShapeSummary.
        :type: str
        """
        self._shape_family = shape_family

    @property
    def default_ocpu_count(self):
        """
        Gets the default_ocpu_count of this SupportedHostShapeSummary.
        The default OCPU count of the shape.


        :return: The default_ocpu_count of this SupportedHostShapeSummary.
        :rtype: float
        """
        return self._default_ocpu_count

    @default_ocpu_count.setter
    def default_ocpu_count(self, default_ocpu_count):
        """
        Sets the default_ocpu_count of this SupportedHostShapeSummary.
        The default OCPU count of the shape.


        :param default_ocpu_count: The default_ocpu_count of this SupportedHostShapeSummary.
        :type: float
        """
        self._default_ocpu_count = default_ocpu_count

    @property
    def supported_ocpu_count(self):
        """
        Gets the supported_ocpu_count of this SupportedHostShapeSummary.
        Support OCPU count of the shape.


        :return: The supported_ocpu_count of this SupportedHostShapeSummary.
        :rtype: list[float]
        """
        return self._supported_ocpu_count

    @supported_ocpu_count.setter
    def supported_ocpu_count(self, supported_ocpu_count):
        """
        Sets the supported_ocpu_count of this SupportedHostShapeSummary.
        Support OCPU count of the shape.


        :param supported_ocpu_count: The supported_ocpu_count of this SupportedHostShapeSummary.
        :type: list[float]
        """
        self._supported_ocpu_count = supported_ocpu_count

    @property
    def supported_sddc_types(self):
        """
        Gets the supported_sddc_types of this SupportedHostShapeSummary.
        The supported SDDC types for the shape.

        Allowed values for items in this list are: "PRODUCTION", "NON_PRODUCTION", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The supported_sddc_types of this SupportedHostShapeSummary.
        :rtype: list[str]
        """
        return self._supported_sddc_types

    @supported_sddc_types.setter
    def supported_sddc_types(self, supported_sddc_types):
        """
        Sets the supported_sddc_types of this SupportedHostShapeSummary.
        The supported SDDC types for the shape.


        :param supported_sddc_types: The supported_sddc_types of this SupportedHostShapeSummary.
        :type: list[str]
        """
        allowed_values = ["PRODUCTION", "NON_PRODUCTION"]
        if supported_sddc_types:
            supported_sddc_types[:] = ['UNKNOWN_ENUM_VALUE' if not value_allowed_none_or_none_sentinel(x, allowed_values) else x for x in supported_sddc_types]
        self._supported_sddc_types = supported_sddc_types

    @property
    def supported_vmware_software_versions(self):
        """
        Gets the supported_vmware_software_versions of this SupportedHostShapeSummary.
        The VMware software versions supported by the shape.


        :return: The supported_vmware_software_versions of this SupportedHostShapeSummary.
        :rtype: list[str]
        """
        return self._supported_vmware_software_versions

    @supported_vmware_software_versions.setter
    def supported_vmware_software_versions(self, supported_vmware_software_versions):
        """
        Sets the supported_vmware_software_versions of this SupportedHostShapeSummary.
        The VMware software versions supported by the shape.


        :param supported_vmware_software_versions: The supported_vmware_software_versions of this SupportedHostShapeSummary.
        :type: list[str]
        """
        self._supported_vmware_software_versions = supported_vmware_software_versions

    @property
    def description(self):
        """
        Gets the description of this SupportedHostShapeSummary.
        Description of the shape.


        :return: The description of this SupportedHostShapeSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this SupportedHostShapeSummary.
        Description of the shape.


        :param description: The description of this SupportedHostShapeSummary.
        :type: str
        """
        self._description = description

    @property
    def is_support_shielded_instances(self):
        """
        Gets the is_support_shielded_instances of this SupportedHostShapeSummary.
        Indicates whether the shape supports shielded instances.


        :return: The is_support_shielded_instances of this SupportedHostShapeSummary.
        :rtype: bool
        """
        return self._is_support_shielded_instances

    @is_support_shielded_instances.setter
    def is_support_shielded_instances(self, is_support_shielded_instances):
        """
        Sets the is_support_shielded_instances of this SupportedHostShapeSummary.
        Indicates whether the shape supports shielded instances.


        :param is_support_shielded_instances: The is_support_shielded_instances of this SupportedHostShapeSummary.
        :type: bool
        """
        self._is_support_shielded_instances = is_support_shielded_instances

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .update_host_dump_transfer_details import UpdateHostDumpTransferDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateOciCliDumpTransferDetails(UpdateHostDumpTransferDetails):
    """
    Optional dump transfer details for OCI-CLI-based dump transfer in source or target host.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateOciCliDumpTransferDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.database_migration.models.UpdateOciCliDumpTransferDetails.kind` attribute
        of this class is ``OCI_CLI`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param kind:
            The value to assign to the kind property of this UpdateOciCliDumpTransferDetails.
            Allowed values for this property are: "CURL", "OCI_CLI"
        :type kind: str

        :param oci_home:
            The value to assign to the oci_home property of this UpdateOciCliDumpTransferDetails.
        :type oci_home: str

        """
        self.swagger_types = {
            'kind': 'str',
            'oci_home': 'str'
        }

        self.attribute_map = {
            'kind': 'kind',
            'oci_home': 'ociHome'
        }

        self._kind = None
        self._oci_home = None
        self._kind = 'OCI_CLI'

    @property
    def oci_home(self):
        """
        **[Required]** Gets the oci_home of this UpdateOciCliDumpTransferDetails.
        Path to the OCI CLI installation in the node.


        :return: The oci_home of this UpdateOciCliDumpTransferDetails.
        :rtype: str
        """
        return self._oci_home

    @oci_home.setter
    def oci_home(self, oci_home):
        """
        Sets the oci_home of this UpdateOciCliDumpTransferDetails.
        Path to the OCI CLI installation in the node.


        :param oci_home: The oci_home of this UpdateOciCliDumpTransferDetails.
        :type: str
        """
        self._oci_home = oci_home

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .create_skill_details import CreateSkillDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CloneSkillDetails(CreateSkillDetails):
    """
    Properties that are required to create a new Skill by cloning an existing Skill.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CloneSkillDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.oda.models.CloneSkillDetails.kind` attribute
        of this class is ``CLONE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param kind:
            The value to assign to the kind property of this CloneSkillDetails.
            Allowed values for this property are: "NEW", "CLONE", "VERSION", "EXTEND"
        :type kind: str

        :param category:
            The value to assign to the category property of this CloneSkillDetails.
        :type category: str

        :param description:
            The value to assign to the description property of this CloneSkillDetails.
        :type description: str

        :param platform_version:
            The value to assign to the platform_version property of this CloneSkillDetails.
        :type platform_version: str

        :param multilingual_mode:
            The value to assign to the multilingual_mode property of this CloneSkillDetails.
            Allowed values for this property are: "NATIVE", "TRANSLATION"
        :type multilingual_mode: str

        :param primary_language_tag:
            The value to assign to the primary_language_tag property of this CloneSkillDetails.
        :type primary_language_tag: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CloneSkillDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CloneSkillDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param id:
            The value to assign to the id property of this CloneSkillDetails.
        :type id: str

        :param name:
            The value to assign to the name property of this CloneSkillDetails.
        :type name: str

        :param display_name:
            The value to assign to the display_name property of this CloneSkillDetails.
        :type display_name: str

        :param version:
            The value to assign to the version property of this CloneSkillDetails.
        :type version: str

        """
        self.swagger_types = {
            'kind': 'str',
            'category': 'str',
            'description': 'str',
            'platform_version': 'str',
            'multilingual_mode': 'str',
            'primary_language_tag': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'id': 'str',
            'name': 'str',
            'display_name': 'str',
            'version': 'str'
        }

        self.attribute_map = {
            'kind': 'kind',
            'category': 'category',
            'description': 'description',
            'platform_version': 'platformVersion',
            'multilingual_mode': 'multilingualMode',
            'primary_language_tag': 'primaryLanguageTag',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'id': 'id',
            'name': 'name',
            'display_name': 'displayName',
            'version': 'version'
        }

        self._kind = None
        self._category = None
        self._description = None
        self._platform_version = None
        self._multilingual_mode = None
        self._primary_language_tag = None
        self._freeform_tags = None
        self._defined_tags = None
        self._id = None
        self._name = None
        self._display_name = None
        self._version = None
        self._kind = 'CLONE'

    @property
    def id(self):
        """
        **[Required]** Gets the id of this CloneSkillDetails.
        The unique identifier of the Skill to clone.


        :return: The id of this CloneSkillDetails.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this CloneSkillDetails.
        The unique identifier of the Skill to clone.


        :param id: The id of this CloneSkillDetails.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        **[Required]** Gets the name of this CloneSkillDetails.
        The reource's name. The name can contain only letters, numbers, periods, and underscores. The name must begin with a letter.


        :return: The name of this CloneSkillDetails.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CloneSkillDetails.
        The reource's name. The name can contain only letters, numbers, periods, and underscores. The name must begin with a letter.


        :param name: The name of this CloneSkillDetails.
        :type: str
        """
        self._name = name

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this CloneSkillDetails.
        The resource's display name.


        :return: The display_name of this CloneSkillDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CloneSkillDetails.
        The resource's display name.


        :param display_name: The display_name of this CloneSkillDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def version(self):
        """
        Gets the version of this CloneSkillDetails.
        The resource's version. The version can only contain numbers, letters, periods, underscores, dashes or spaces.  The version must begin with a letter or a number.


        :return: The version of this CloneSkillDetails.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this CloneSkillDetails.
        The resource's version. The version can only contain numbers, letters, periods, underscores, dashes or spaces.  The version must begin with a letter or a number.


        :param version: The version of this CloneSkillDetails.
        :type: str
        """
        self._version = version

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AggregatorSummary(object):
    """
    A summary type containing information about the object's aggregator including its type, key, name and description.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AggregatorSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this AggregatorSummary.
        :type type: str

        :param key:
            The value to assign to the key property of this AggregatorSummary.
        :type key: str

        :param name:
            The value to assign to the name property of this AggregatorSummary.
        :type name: str

        :param identifier:
            The value to assign to the identifier property of this AggregatorSummary.
        :type identifier: str

        :param description:
            The value to assign to the description property of this AggregatorSummary.
        :type description: str

        """
        self.swagger_types = {
            'type': 'str',
            'key': 'str',
            'name': 'str',
            'identifier': 'str',
            'description': 'str'
        }

        self.attribute_map = {
            'type': 'type',
            'key': 'key',
            'name': 'name',
            'identifier': 'identifier',
            'description': 'description'
        }

        self._type = None
        self._key = None
        self._name = None
        self._identifier = None
        self._description = None

    @property
    def type(self):
        """
        Gets the type of this AggregatorSummary.
        The type of the aggregator.


        :return: The type of this AggregatorSummary.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this AggregatorSummary.
        The type of the aggregator.


        :param type: The type of this AggregatorSummary.
        :type: str
        """
        self._type = type

    @property
    def key(self):
        """
        Gets the key of this AggregatorSummary.
        The key of the aggregator object.


        :return: The key of this AggregatorSummary.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this AggregatorSummary.
        The key of the aggregator object.


        :param key: The key of this AggregatorSummary.
        :type: str
        """
        self._key = key

    @property
    def name(self):
        """
        Gets the name of this AggregatorSummary.
        The name of the aggregator.


        :return: The name of this AggregatorSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this AggregatorSummary.
        The name of the aggregator.


        :param name: The name of this AggregatorSummary.
        :type: str
        """
        self._name = name

    @property
    def identifier(self):
        """
        Gets the identifier of this AggregatorSummary.
        The identifier of the aggregator.


        :return: The identifier of this AggregatorSummary.
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """
        Sets the identifier of this AggregatorSummary.
        The identifier of the aggregator.


        :param identifier: The identifier of this AggregatorSummary.
        :type: str
        """
        self._identifier = identifier

    @property
    def description(self):
        """
        Gets the description of this AggregatorSummary.
        The description of the aggregator.


        :return: The description of this AggregatorSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this AggregatorSummary.
        The description of the aggregator.


        :param description: The description of this AggregatorSummary.
        :type: str
        """
        self._description = description

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateVolumeBackupPolicyDetails(object):
    """
    Specifies the properties for updating a user defined backup policy.
    For more information about user defined backup policies,
    see `User Defined Policies`__ in
    `Policy-Based Backups`__.

    __ https://docs.cloud.oracle.com/iaas/Content/Block/Tasks/schedulingvolumebackups.htm#UserDefinedBackupPolicies
    __ https://docs.cloud.oracle.com/iaas/Content/Block/Tasks/schedulingvolumebackups.htm
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateVolumeBackupPolicyDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this UpdateVolumeBackupPolicyDetails.
        :type display_name: str

        :param destination_region:
            The value to assign to the destination_region property of this UpdateVolumeBackupPolicyDetails.
        :type destination_region: str

        :param schedules:
            The value to assign to the schedules property of this UpdateVolumeBackupPolicyDetails.
        :type schedules: list[oci.core.models.VolumeBackupSchedule]

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateVolumeBackupPolicyDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateVolumeBackupPolicyDetails.
        :type freeform_tags: dict(str, str)

        """
        self.swagger_types = {
            'display_name': 'str',
            'destination_region': 'str',
            'schedules': 'list[VolumeBackupSchedule]',
            'defined_tags': 'dict(str, dict(str, object))',
            'freeform_tags': 'dict(str, str)'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'destination_region': 'destinationRegion',
            'schedules': 'schedules',
            'defined_tags': 'definedTags',
            'freeform_tags': 'freeformTags'
        }

        self._display_name = None
        self._destination_region = None
        self._schedules = None
        self._defined_tags = None
        self._freeform_tags = None

    @property
    def display_name(self):
        """
        Gets the display_name of this UpdateVolumeBackupPolicyDetails.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :return: The display_name of this UpdateVolumeBackupPolicyDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this UpdateVolumeBackupPolicyDetails.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this UpdateVolumeBackupPolicyDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def destination_region(self):
        """
        Gets the destination_region of this UpdateVolumeBackupPolicyDetails.
        The paired destination region for copying scheduled backups to. Example: `us-ashburn-1`.
        Specify `none` to reset the `destinationRegion` parameter.
        See `Region Pairs`__ for details about paired regions.

        __ https://docs.cloud.oracle.com/iaas/Content/Block/Tasks/schedulingvolumebackups.htm#RegionPairs


        :return: The destination_region of this UpdateVolumeBackupPolicyDetails.
        :rtype: str
        """
        return self._destination_region

    @destination_region.setter
    def destination_region(self, destination_region):
        """
        Sets the destination_region of this UpdateVolumeBackupPolicyDetails.
        The paired destination region for copying scheduled backups to. Example: `us-ashburn-1`.
        Specify `none` to reset the `destinationRegion` parameter.
        See `Region Pairs`__ for details about paired regions.

        __ https://docs.cloud.oracle.com/iaas/Content/Block/Tasks/schedulingvolumebackups.htm#RegionPairs


        :param destination_region: The destination_region of this UpdateVolumeBackupPolicyDetails.
        :type: str
        """
        self._destination_region = destination_region

    @property
    def schedules(self):
        """
        Gets the schedules of this UpdateVolumeBackupPolicyDetails.
        The collection of schedules for the volume backup policy. See
        see `Schedules`__ in
        `Policy-Based Backups`__ for more information.

        __ https://docs.cloud.oracle.com/iaas/Content/Block/Tasks/schedulingvolumebackups.htm#schedules
        __ https://docs.cloud.oracle.com/iaas/Content/Block/Tasks/schedulingvolumebackups.htm


        :return: The schedules of this UpdateVolumeBackupPolicyDetails.
        :rtype: list[oci.core.models.VolumeBackupSchedule]
        """
        return self._schedules

    @schedules.setter
    def schedules(self, schedules):
        """
        Sets the schedules of this UpdateVolumeBackupPolicyDetails.
        The collection of schedules for the volume backup policy. See
        see `Schedules`__ in
        `Policy-Based Backups`__ for more information.

        __ https://docs.cloud.oracle.com/iaas/Content/Block/Tasks/schedulingvolumebackups.htm#schedules
        __ https://docs.cloud.oracle.com/iaas/Content/Block/Tasks/schedulingvolumebackups.htm


        :param schedules: The schedules of this UpdateVolumeBackupPolicyDetails.
        :type: list[oci.core.models.VolumeBackupSchedule]
        """
        self._schedules = schedules

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this UpdateVolumeBackupPolicyDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this UpdateVolumeBackupPolicyDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this UpdateVolumeBackupPolicyDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this UpdateVolumeBackupPolicyDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this UpdateVolumeBackupPolicyDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this UpdateVolumeBackupPolicyDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this UpdateVolumeBackupPolicyDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this UpdateVolumeBackupPolicyDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .host_performance_metric_group import HostPerformanceMetricGroup
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class HostTopProcesses(HostPerformanceMetricGroup):
    """
    Top Processes metric for the host
    """

    def __init__(self, **kwargs):
        """
        Initializes a new HostTopProcesses object with values from keyword arguments. The default value of the :py:attr:`~oci.opsi.models.HostTopProcesses.metric_name` attribute
        of this class is ``HOST_TOP_PROCESSES`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param metric_name:
            The value to assign to the metric_name property of this HostTopProcesses.
            Allowed values for this property are: "HOST_CPU_USAGE", "HOST_MEMORY_USAGE", "HOST_NETWORK_ACTIVITY_SUMMARY", "HOST_TOP_PROCESSES"
        :type metric_name: str

        :param time_collected:
            The value to assign to the time_collected property of this HostTopProcesses.
        :type time_collected: datetime

        :param pid:
            The value to assign to the pid property of this HostTopProcesses.
        :type pid: float

        :param user_name:
            The value to assign to the user_name property of this HostTopProcesses.
        :type user_name: str

        :param memory_utilization_percent:
            The value to assign to the memory_utilization_percent property of this HostTopProcesses.
        :type memory_utilization_percent: float

        :param cpu_utilization_percent:
            The value to assign to the cpu_utilization_percent property of this HostTopProcesses.
        :type cpu_utilization_percent: float

        :param cpu_usage_in_seconds:
            The value to assign to the cpu_usage_in_seconds property of this HostTopProcesses.
        :type cpu_usage_in_seconds: float

        :param command:
            The value to assign to the command property of this HostTopProcesses.
        :type command: str

        :param virtual_memory_in_mbs:
            The value to assign to the virtual_memory_in_mbs property of this HostTopProcesses.
        :type virtual_memory_in_mbs: float

        :param physical_memory_in_mbs:
            The value to assign to the physical_memory_in_mbs property of this HostTopProcesses.
        :type physical_memory_in_mbs: float

        :param start_time:
            The value to assign to the start_time property of this HostTopProcesses.
        :type start_time: datetime

        :param total_processes:
            The value to assign to the total_processes property of this HostTopProcesses.
        :type total_processes: float

        """
        self.swagger_types = {
            'metric_name': 'str',
            'time_collected': 'datetime',
            'pid': 'float',
            'user_name': 'str',
            'memory_utilization_percent': 'float',
            'cpu_utilization_percent': 'float',
            'cpu_usage_in_seconds': 'float',
            'command': 'str',
            'virtual_memory_in_mbs': 'float',
            'physical_memory_in_mbs': 'float',
            'start_time': 'datetime',
            'total_processes': 'float'
        }

        self.attribute_map = {
            'metric_name': 'metricName',
            'time_collected': 'timeCollected',
            'pid': 'pid',
            'user_name': 'userName',
            'memory_utilization_percent': 'memoryUtilizationPercent',
            'cpu_utilization_percent': 'cpuUtilizationPercent',
            'cpu_usage_in_seconds': 'cpuUsageInSeconds',
            'command': 'command',
            'virtual_memory_in_mbs': 'virtualMemoryInMBs',
            'physical_memory_in_mbs': 'physicalMemoryInMBs',
            'start_time': 'startTime',
            'total_processes': 'totalProcesses'
        }

        self._metric_name = None
        self._time_collected = None
        self._pid = None
        self._user_name = None
        self._memory_utilization_percent = None
        self._cpu_utilization_percent = None
        self._cpu_usage_in_seconds = None
        self._command = None
        self._virtual_memory_in_mbs = None
        self._physical_memory_in_mbs = None
        self._start_time = None
        self._total_processes = None
        self._metric_name = 'HOST_TOP_PROCESSES'

    @property
    def pid(self):
        """
        Gets the pid of this HostTopProcesses.
        process id


        :return: The pid of this HostTopProcesses.
        :rtype: float
        """
        return self._pid

    @pid.setter
    def pid(self, pid):
        """
        Sets the pid of this HostTopProcesses.
        process id


        :param pid: The pid of this HostTopProcesses.
        :type: float
        """
        self._pid = pid

    @property
    def user_name(self):
        """
        Gets the user_name of this HostTopProcesses.
        User that started the process


        :return: The user_name of this HostTopProcesses.
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """
        Sets the user_name of this HostTopProcesses.
        User that started the process


        :param user_name: The user_name of this HostTopProcesses.
        :type: str
        """
        self._user_name = user_name

    @property
    def memory_utilization_percent(self):
        """
        Gets the memory_utilization_percent of this HostTopProcesses.
        Memory utilization percentage


        :return: The memory_utilization_percent of this HostTopProcesses.
        :rtype: float
        """
        return self._memory_utilization_percent

    @memory_utilization_percent.setter
    def memory_utilization_percent(self, memory_utilization_percent):
        """
        Sets the memory_utilization_percent of this HostTopProcesses.
        Memory utilization percentage


        :param memory_utilization_percent: The memory_utilization_percent of this HostTopProcesses.
        :type: float
        """
        self._memory_utilization_percent = memory_utilization_percent

    @property
    def cpu_utilization_percent(self):
        """
        Gets the cpu_utilization_percent of this HostTopProcesses.
        CPU utilization percentage


        :return: The cpu_utilization_percent of this HostTopProcesses.
        :rtype: float
        """
        return self._cpu_utilization_percent

    @cpu_utilization_percent.setter
    def cpu_utilization_percent(self, cpu_utilization_percent):
        """
        Sets the cpu_utilization_percent of this HostTopProcesses.
        CPU utilization percentage


        :param cpu_utilization_percent: The cpu_utilization_percent of this HostTopProcesses.
        :type: float
        """
        self._cpu_utilization_percent = cpu_utilization_percent

    @property
    def cpu_usage_in_seconds(self):
        """
        Gets the cpu_usage_in_seconds of this HostTopProcesses.
        CPU usage in seconds


        :return: The cpu_usage_in_seconds of this HostTopProcesses.
        :rtype: float
        """
        return self._cpu_usage_in_seconds

    @cpu_usage_in_seconds.setter
    def cpu_usage_in_seconds(self, cpu_usage_in_seconds):
        """
        Sets the cpu_usage_in_seconds of this HostTopProcesses.
        CPU usage in seconds


        :param cpu_usage_in_seconds: The cpu_usage_in_seconds of this HostTopProcesses.
        :type: float
        """
        self._cpu_usage_in_seconds = cpu_usage_in_seconds

    @property
    def command(self):
        """
        Gets the command of this HostTopProcesses.
        Command line executed for the process


        :return: The command of this HostTopProcesses.
        :rtype: str
        """
        return self._command

    @command.setter
    def command(self, command):
        """
        Sets the command of this HostTopProcesses.
        Command line executed for the process


        :param command: The command of this HostTopProcesses.
        :type: str
        """
        self._command = command

    @property
    def virtual_memory_in_mbs(self):
        """
        Gets the virtual_memory_in_mbs of this HostTopProcesses.
        Virtual memory in megabytes


        :return: The virtual_memory_in_mbs of this HostTopProcesses.
        :rtype: float
        """
        return self._virtual_memory_in_mbs

    @virtual_memory_in_mbs.setter
    def virtual_memory_in_mbs(self, virtual_memory_in_mbs):
        """
        Sets the virtual_memory_in_mbs of this HostTopProcesses.
        Virtual memory in megabytes


        :param virtual_memory_in_mbs: The virtual_memory_in_mbs of this HostTopProcesses.
        :type: float
        """
        self._virtual_memory_in_mbs = virtual_memory_in_mbs

    @property
    def physical_memory_in_mbs(self):
        """
        Gets the physical_memory_in_mbs of this HostTopProcesses.
        Physical memory in megabytes


        :return: The physical_memory_in_mbs of this HostTopProcesses.
        :rtype: float
        """
        return self._physical_memory_in_mbs

    @physical_memory_in_mbs.setter
    def physical_memory_in_mbs(self, physical_memory_in_mbs):
        """
        Sets the physical_memory_in_mbs of this HostTopProcesses.
        Physical memory in megabytes


        :param physical_memory_in_mbs: The physical_memory_in_mbs of this HostTopProcesses.
        :type: float
        """
        self._physical_memory_in_mbs = physical_memory_in_mbs

    @property
    def start_time(self):
        """
        Gets the start_time of this HostTopProcesses.
        Process Start Time
        Example: `\"2020-03-31T00:00:00.000Z\"`


        :return: The start_time of this HostTopProcesses.
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """
        Sets the start_time of this HostTopProcesses.
        Process Start Time
        Example: `\"2020-03-31T00:00:00.000Z\"`


        :param start_time: The start_time of this HostTopProcesses.
        :type: datetime
        """
        self._start_time = start_time

    @property
    def total_processes(self):
        """
        Gets the total_processes of this HostTopProcesses.
        Number of processes running at the time of collection


        :return: The total_processes of this HostTopProcesses.
        :rtype: float
        """
        return self._total_processes

    @total_processes.setter
    def total_processes(self, total_processes):
        """
        Sets the total_processes of this HostTopProcesses.
        Number of processes running at the time of collection


        :param total_processes: The total_processes of this HostTopProcesses.
        :type: float
        """
        self._total_processes = total_processes

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AlertAggregationItems(object):
    """
    Details of alerts aggregation items.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AlertAggregationItems object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param metric_name:
            The value to assign to the metric_name property of this AlertAggregationItems.
        :type metric_name: str

        :param time_started:
            The value to assign to the time_started property of this AlertAggregationItems.
        :type time_started: datetime

        :param time_ended:
            The value to assign to the time_ended property of this AlertAggregationItems.
        :type time_ended: datetime

        :param count:
            The value to assign to the count property of this AlertAggregationItems.
        :type count: int

        :param dimensions:
            The value to assign to the dimensions property of this AlertAggregationItems.
        :type dimensions: oci.data_safe.models.AlertsAggregationDimension

        """
        self.swagger_types = {
            'metric_name': 'str',
            'time_started': 'datetime',
            'time_ended': 'datetime',
            'count': 'int',
            'dimensions': 'AlertsAggregationDimension'
        }

        self.attribute_map = {
            'metric_name': 'metricName',
            'time_started': 'timeStarted',
            'time_ended': 'timeEnded',
            'count': 'count',
            'dimensions': 'dimensions'
        }

        self._metric_name = None
        self._time_started = None
        self._time_ended = None
        self._count = None
        self._dimensions = None

    @property
    def metric_name(self):
        """
        **[Required]** Gets the metric_name of this AlertAggregationItems.
        The name of the aggregation.


        :return: The metric_name of this AlertAggregationItems.
        :rtype: str
        """
        return self._metric_name

    @metric_name.setter
    def metric_name(self, metric_name):
        """
        Sets the metric_name of this AlertAggregationItems.
        The name of the aggregation.


        :param metric_name: The metric_name of this AlertAggregationItems.
        :type: str
        """
        self._metric_name = metric_name

    @property
    def time_started(self):
        """
        **[Required]** Gets the time_started of this AlertAggregationItems.
        The time at which the aggregation started.


        :return: The time_started of this AlertAggregationItems.
        :rtype: datetime
        """
        return self._time_started

    @time_started.setter
    def time_started(self, time_started):
        """
        Sets the time_started of this AlertAggregationItems.
        The time at which the aggregation started.


        :param time_started: The time_started of this AlertAggregationItems.
        :type: datetime
        """
        self._time_started = time_started

    @property
    def time_ended(self):
        """
        **[Required]** Gets the time_ended of this AlertAggregationItems.
        The time at which the aggregation ended.


        :return: The time_ended of this AlertAggregationItems.
        :rtype: datetime
        """
        return self._time_ended

    @time_ended.setter
    def time_ended(self, time_ended):
        """
        Sets the time_ended of this AlertAggregationItems.
        The time at which the aggregation ended.


        :param time_ended: The time_ended of this AlertAggregationItems.
        :type: datetime
        """
        self._time_ended = time_ended

    @property
    def count(self):
        """
        **[Required]** Gets the count of this AlertAggregationItems.
        Total count of aggregated values.


        :return: The count of this AlertAggregationItems.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """
        Sets the count of this AlertAggregationItems.
        Total count of aggregated values.


        :param count: The count of this AlertAggregationItems.
        :type: int
        """
        self._count = count

    @property
    def dimensions(self):
        """
        Gets the dimensions of this AlertAggregationItems.

        :return: The dimensions of this AlertAggregationItems.
        :rtype: oci.data_safe.models.AlertsAggregationDimension
        """
        return self._dimensions

    @dimensions.setter
    def dimensions(self, dimensions):
        """
        Sets the dimensions of this AlertAggregationItems.

        :param dimensions: The dimensions of this AlertAggregationItems.
        :type: oci.data_safe.models.AlertsAggregationDimension
        """
        self._dimensions = dimensions

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
